diff --git a/Scripts/Bash/Functions/Commons/synchronizeRepoChanges.sh b/Scripts/Bash/Functions/Commons/synchronizeRepoChanges.sh
index 1056646..216f7f5 100755
--- a/Scripts/Bash/Functions/Commons/synchronizeRepoChanges.sh
+++ b/Scripts/Bash/Functions/Commons/synchronizeRepoChanges.sh
@@ -1,6 +1,6 @@
 #!/bin/bash
 #
 # cli_syncronizeRepoChanges.sh -- This function standardizes the way
 # changes are synchronized between the working copy and the central
 # repository. This function is an interface for the `Svn'
 # functionality of centos-art.sh script.
@@ -25,7 +25,7 @@
 # $Id$
 # ----------------------------------------------------------------------
 
-function cli_syncronizeRepoChanges {
+function cli_synchronizeRepoChanges {
 
     if [[ ! $FLAG_COMMIT_CHANGES == 'true' ]];then
         return
@@ -1,6 +1,6 @@
 #!/bin/bash
 #
-# cli_syncronizeRepoChanges.sh -- This function standardizes the way
+# cli_synchronizeRepoChanges.sh -- This function standardizes the way
 # changes are synchronized between the working copy and the central
 # repository. This function is an interface for the `Svn'